Learn R Programming

SSRA (version 0.1-1)

SSRA: Sakai Sequential Relation Analysis

Description

This function conducts the Sequential Relation Analysis based on Sakai 2016

Usage

SSRA(dat, r.crt = 0.3, mu.sq = 0, mu.eq = Inf, d.sq = 0.2, d.eq = 0.2,
  pairwise = TRUE, method = c("pearson", "kendall", "spearman"),
  alpha = 0.05, p.adjust.method = c("holm", "hochberg", "hommel",
  "bonferroni", "BH", "BY", "fdr", "none"), digits = 3, vnames = TRUE,
  order = c("no", "decreasing", "increasing"), exclude = TRUE,
  output = TRUE)

Value

Returns an object of class ssra, to be used for the seqtable function. The object is a list with following entries: 'dat' (data frame), 'call" (function call), 'args' (specification of arguments), 'time' (time of analysis), 'R' (R version), 'package' (package version), and 'restab' (result table). The 'restab' entry has following entries:

jitem j
kitem k
nsample size
j.meanmean of item j
j.sdstandard deviation of item j
k.meanmean of item k
k.sdstandard deviation of item k
rcorrelation coefficient
r.ttest statistic of the statistical significanc test for the correlation coefficient
r.pstatistical significance value of the correlation
r.sigstatistical significance of the correlation (0 = not significant / 1 = significant)
r.crtcorrelation criterion for judging 'sequential' or 'equal': 'r.p < alpha' and 'r > r.crt' (0 = no / 1 = yes)
m.diffmean difference
sd.diffstandard deviation difference
m.diff.effeffect size Cohen's d for dependent samples
m.ttest statistic of the statistical significanc test for mean difference
m.pstatistical significance value of the mean difference
m.sigstatistical significance of the mean difference (0 = not significant / 1 = significant)
m.crt.sqmean difference criteria for judging 'sequential': 'm.diff.p < alpha', 'm.diff > mu.sq' and 'm.diff.eff > d.sq' (0 = no / -1 = yes negative / 1 = yes postive)
m.crt.eqmean difference criteria for judging 'equivalence': statistical significant and 'm <= mu.eq' 'd <= d.sq' (0 = no 1 = yes)
seqsequential relation of item pairs ("+","-", "")
eqequivalence of item pairs ("=" or "")
orderorder structure of item pairs ("=", "+","-")

Arguments

dat

requires a data frame with polytomous data

r.crt

correlation coefficient criterion to be judged 'sequential' or 'equivalent

mu.sq

Absolute mean difference criterion to be judged 'sequential'

mu.eq

maximal absolute mean difference to be judged 'equivalent'

d.sq

effect size for mean difference criterion to be judged 'sequential'

d.eq

maximal effect size Cohen's d to be judged 'equivalent'

pairwise

pairwise deletion of missing data, if pairwise = FALSE listwise deletion is applied

method

character string indicating which correlation coefficient to be used, 'pearson' = Pearson's product moment correlation coefficien 'spearman' = Spearman's rho statistic 'kendall' = Kendall's tau (default)

alpha

significance level

p.adjust.method

p-value correction method for multiple comparisons, see: ?p.adjust (default = holm)

digits

integer indicating the number of decimal places to be used

vnames

use variable names for labeling?

order

sort by item mean of j and k?

exclude

exclude paths with no relationship?

output

print result table?

Author

Takuya Yanagida Keiko Sakai

Details

Takea Semantic Structure Analysis (TSSA) and Sakai Sequential Relation Analysis (SSRA) are graphical approaches

References

Takeya, M. (1991). A new test theory: Structural analyses for educational information. Tokyo: Waseda University Press.

See Also

seqtable, TSSA, plot.ssra, scatterplot

Examples

Run this code
# Example data based on Takeya (1991)

# Sakai Sequential Relation Analysis
# ordering assesed according to the correlation coefficient and mean difference
SSRA(exdat)

Run the code above in your browser using DataLab