This function conducts the Sequential Relation Analysis based on Sakai 2016
SSRA(dat, r.crt = 0.3, mu.sq = 0, mu.eq = Inf, d.sq = 0.2, d.eq = 0.2,
pairwise = TRUE, method = c("pearson", "kendall", "spearman"),
alpha = 0.05, p.adjust.method = c("holm", "hochberg", "hommel",
"bonferroni", "BH", "BY", "fdr", "none"), digits = 3, vnames = TRUE,
order = c("no", "decreasing", "increasing"), exclude = TRUE,
output = TRUE)Returns an object of class ssra, to be used for the seqtable function. The object is a list with
following entries: 'dat' (data frame), 'call" (function call), 'args' (specification of arguments),
'time' (time of analysis), 'R' (R version), 'package' (package version), and 'restab' (result table).
The 'restab' entry has following entries:
j | item j |
k | item k |
n | sample size |
j.mean | mean of item j |
j.sd | standard deviation of item j |
k.mean | mean of item k |
k.sd | standard deviation of item k |
r | correlation coefficient |
r.t | test statistic of the statistical significanc test for the correlation coefficient |
r.p | statistical significance value of the correlation |
r.sig | statistical significance of the correlation (0 = not significant / 1 = significant) |
r.crt | correlation criterion for judging 'sequential' or 'equal': 'r.p < alpha' and 'r > r.crt' (0 = no / 1 = yes) |
m.diff | mean difference |
sd.diff | standard deviation difference |
m.diff.eff | effect size Cohen's d for dependent samples |
m.t | test statistic of the statistical significanc test for mean difference |
m.p | statistical significance value of the mean difference |
m.sig | statistical significance of the mean difference (0 = not significant / 1 = significant) |
m.crt.sq | mean difference criteria for judging 'sequential': 'm.diff.p < alpha', 'm.diff > mu.sq' and 'm.diff.eff > d.sq' (0 = no / -1 = yes negative / 1 = yes postive) |
m.crt.eq | mean difference criteria for judging 'equivalence': statistical significant and 'm <= mu.eq' 'd <= d.sq' (0 = no 1 = yes) |
seq | sequential relation of item pairs ("+","-", "") |
eq | equivalence of item pairs ("=" or "") |
order | order structure of item pairs ("=", "+","-") |
requires a data frame with polytomous data
correlation coefficient criterion to be judged 'sequential' or 'equivalent
Absolute mean difference criterion to be judged 'sequential'
maximal absolute mean difference to be judged 'equivalent'
effect size for mean difference criterion to be judged 'sequential'
maximal effect size Cohen's d to be judged 'equivalent'
pairwise deletion of missing data, if pairwise = FALSE listwise deletion is applied
character string indicating which correlation coefficient to be used, 'pearson' = Pearson's product moment correlation coefficien 'spearman' = Spearman's rho statistic 'kendall' = Kendall's tau (default)
significance level
p-value correction method for multiple comparisons, see: ?p.adjust (default = holm)
integer indicating the number of decimal places to be used
use variable names for labeling?
sort by item mean of j and k?
exclude paths with no relationship?
print result table?
Takuya Yanagida Keiko Sakai
Takea Semantic Structure Analysis (TSSA) and Sakai Sequential Relation Analysis (SSRA) are graphical approaches
Takeya, M. (1991). A new test theory: Structural analyses for educational information. Tokyo: Waseda University Press.
seqtable, TSSA, plot.ssra, scatterplot
# Example data based on Takeya (1991)
# Sakai Sequential Relation Analysis
# ordering assesed according to the correlation coefficient and mean difference
SSRA(exdat)
Run the code above in your browser using DataLab